@@ -1,10 +1,11 @@
 package MooseX::Role::Flyweight;
 {
-  $MooseX::Role::Flyweight::VERSION = '0.007';
+  $MooseX::Role::Flyweight::VERSION = '1.00';
 }
 # ABSTRACT: Automatically memoize your Moose objects for reuse
 
 
+use 5.006;
 use JSON 2.00 (); # works with JSON::XS
 use Moose::Role;
 use MooseX::ClassAttribute 0.23; # works with roles
@@ -56,11 +57,11 @@ MooseX::Role::Flyweight - Automatically memoize your Moose objects for reuse
 
 =head1 VERSION
 
-version 0.007
+version 1.00
 
 =head1 SYNOPSIS
 
-Conpose MooseX::Role::Flyweight into your Moose class.
+Compose MooseX::Role::Flyweight into your Moose class.
 
     package Glyph::Character;
     use Moose;
@@ -119,8 +120,8 @@ MooseX::Role::Flyweight is used to facilitate the reuse of objects to reduce
 the cost of having many instances. The number of instances created will be
 reduced, but it does not set a limit on how many instances are allowed. Its
 C<instance()> method does accept construction arguments because it is
-responsible for managing the construction of new instances when it finds that
-it cannot reuse an existing one.
+responsible for managing the construction of new instances when it finds
+that it cannot reuse an existing one.
 
 =back
 
@@ -197,8 +198,8 @@ There is no distinction between hash and hashref (and non-hash) arguments.
 The order of named parameters does not affect equivalency.
 
 The keys in the hash(ref) are sorted, which means that the same string will
-always be produced for the same named parameters regardless of the order they
-are given.
+always be produced for the same named parameters regardless of the order
+they are given.
 
     # same object is returned
     $obj1 = My::Flyweight->instance( attr1 => 1, attr2 => 2 );
@@ -244,16 +245,20 @@ of scope.
     undef $obj;
     # $obj is garbage collected and disappears from the cache
 
+=head1 AUTHOR
+
+Steven Lee <stevenwh.lee@gmail.com>
+
+=head1 ACKNOWLEDGEMENTS
+
+Mark Stosberg (MARKSTOS) for suggesting to explain the difference to Singleton.
+
 =head1 SEE ALSO
 
 L<Perl Design Patterns|http://www.perl.com/pub/2003/06/13/design1.html>
 
 L<Memoize>
 
-=head1 AUTHOR
-
-Steven Lee <stevenwh.lee@gmail.com>
-
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2013 by Steven Lee.
